<?php

namespace TVn7\LogBundle\DependencyInjection;

use Symfony\Component\Config\Definition\Builder\TreeBuilder;
use Symfony\Component\Config\Definition\ConfigurationInterface;

use Monolog\Logger;

/**
 * This is the class that validates and merges configuration from your app/config files
 *
 * To learn more see {@link http://symfony.com/doc/current/cookbook/bundles/extension.html#cookbook-bundles-extension-config-class}
 */
class Configuration implements ConfigurationInterface
{
    /**
     * {@inheritDoc}
     */
    public function getConfigTreeBuilder()
    {
        $treeBuilder = new TreeBuilder();
        $rootNode = $treeBuilder->root('t_vn7_log')
                ->children()
                    ->integerNode("max_logs_per_page")
                        ->isRequired()
                        ->defaultValue(50)
                        ->min(1)
                    ->end()
                    ->integerNode("max_page_in_selector")
                        ->isRequired()
                        ->defaultValue(5)
                        ->min(5)
                        ->validate()
                        ->ifTrue(function ($nb) { return !($nb%2); })
                            ->thenInvalid("max_page_in_selector must be odd. %s given.")
                        ->end()
                    ->end()
                    ->arrayNode('db_logger')
                        ->useAttributeAsKey('channel')
                        ->ArrayPrototype()
                        ->children()
                            ->scalarNode('level')
                                ->isRequired()
                                ->cannotBeEmpty()
                                ->validate()
                                ->ifTrue(function($level) {
                                    return !array_key_exists(strtoupper($level), Logger::getLevels());
                                })
                                    ->thenInvalid(sprintf("Level should be one of %s", join(', ', array_keys(Logger::getLevels()))))
                                ->end()
                            ->end()
                        ->end()
                    ->end()
                    ->end()
                    ->scalarNode('default_level')
                        ->isRequired()
                        ->cannotBeEmpty()
                        ->validate()
                        ->ifTrue(function($level) {
                            return !array_key_exists(strtoupper($level), Logger::getLevels());
                        })
                            ->thenInvalid(sprintf("Level should be one of %s", join(', ', array_keys(Logger::getLevels()))))
                        ->end()
                   ->end()
                ->end();

        return $treeBuilder;
    }
}
